simple_locale library

Classes

LocaleManager
(en) A InheritedWidget for controlling locale within an app. /// Any widget that calls LocaleManager.of(context) from this class will automatically be rebuilt and updated when the locale is changed.
LocalizedApp
(en) A base widget for propagating locale changes to child widget. If you want to change the locale dynamically within your app, use this as a parent widget such as MaterialApp.